_me = obj_tab_close.prototype;
function obj_tab_close(){};

_me.__constructor = async function(){

	var me = this;

    addcss(this.__eLi,'obj_tab_close_link');

	this.__eLi.onmousedown = function(e){
		e.preventDefault();
		e.stopPropagation();

		if (e.target.parentElement.tagName == 'B' && !e.button){
			me._close();
		}
		else
			me._active(null, true);
	};
};

_me._value = function(v,bNoLang){
	if (v){
		this.__tabTitle = v;
		this.__eLi.innerHTML = '<span>'+(bNoLang?v:getLang(v))+'</span><b><span></span></b>';
	}
	else
	    return this.__tabTitle || '';
};
